<p align="center"><a href="#"><img width=100% alt="" src="resources/logo.png"></a></p>

# pystreaming

[![PyPI version](https://badge.fury.io/py/pystreaming.svg)](https://badge.fury.io/py/pystreaming)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
<!-- Build -->
<!-- Docs  -->
<!-- Code Cov??? -->

Easy streaming of video and audio using python. NO ffmpeg, NO gstreamer.